@@ -64,6 +64,7 @@ from .type_defs import (
     DeleteGlobalClusterResultTypeDef,
     DescribeDBClusterSnapshotAttributesResultTypeDef,
     DescribeEngineDefaultClusterParametersResultTypeDef,
+    EmptyResponseMetadataTypeDef,
     EventCategoriesMessageTypeDef,
     EventsMessageTypeDef,
     EventSubscriptionsMessageTypeDef,
@@ -196,7 +197,9 @@ class DocDBClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/client/#add_source_identifier_to_subscription)
         """
 
-    def add_tags_to_resource(self, *, ResourceName: str, Tags: Sequence["TagTypeDef"]) -> None:
+    def add_tags_to_resource(
+        self, *, ResourceName: str, Tags: Sequence[TagTypeDef]
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Adds metadata tags to an Amazon DocumentDB resource.
 
@@ -229,7 +232,7 @@ class DocDBClient(BaseClient):
         SourceDBClusterParameterGroupIdentifier: str,
         TargetDBClusterParameterGroupIdentifier: str,
         TargetDBClusterParameterGroupDescription: str,
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence[TagTypeDef] = ...
     ) -> CopyDBClusterParameterGroupResultTypeDef:
         """
         Copies the specified cluster parameter group.
@@ -246,7 +249,7 @@ class DocDBClient(BaseClient):
         KmsKeyId: str = ...,
         PreSignedUrl: str = ...,
         CopyTags: bool = ...,
-        Tags: Sequence["TagTypeDef"] = ...,
+        Tags: Sequence[TagTypeDef] = ...,
         SourceRegion: str = ...
     ) -> CopyDBClusterSnapshotResultTypeDef:
         """
@@ -272,7 +275,7 @@ class DocDBClient(BaseClient):
         MasterUserPassword: str = ...,
         PreferredBackupWindow: str = ...,
         PreferredMaintenanceWindow: str = ...,
-        Tags: Sequence["TagTypeDef"] = ...,
+        Tags: Sequence[TagTypeDef] = ...,
         StorageEncrypted: bool = ...,
         KmsKeyId: str = ...,
         PreSignedUrl: str = ...,
@@ -294,7 +297,7 @@ class DocDBClient(BaseClient):
         DBClusterParameterGroupName: str,
         DBParameterGroupFamily: str,
         Description: str,
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence[TagTypeDef] = ...
     ) -> CreateDBClusterParameterGroupResultTypeDef:
         """
         Creates a new cluster parameter group.
@@ -308,7 +311,7 @@ class DocDBClient(BaseClient):
         *,
         DBClusterSnapshotIdentifier: str,
         DBClusterIdentifier: str,
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence[TagTypeDef] = ...
     ) -> CreateDBClusterSnapshotResultTypeDef:
         """
         Creates a snapshot of a cluster.
@@ -327,7 +330,7 @@ class DocDBClient(BaseClient):
         AvailabilityZone: str = ...,
         PreferredMaintenanceWindow: str = ...,
         AutoMinorVersionUpgrade: bool = ...,
-        Tags: Sequence["TagTypeDef"] = ...,
+        Tags: Sequence[TagTypeDef] = ...,
         PromotionTier: int = ...,
         EnablePerformanceInsights: bool = ...,
         PerformanceInsightsKMSKeyId: str = ...
@@ -345,7 +348,7 @@ class DocDBClient(BaseClient):
         DBSubnetGroupName: str,
         DBSubnetGroupDescription: str,
         SubnetIds: Sequence[str],
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence[TagTypeDef] = ...
     ) -> CreateDBSubnetGroupResultTypeDef:
         """
         Creates a new subnet group.
@@ -363,7 +366,7 @@ class DocDBClient(BaseClient):
         EventCategories: Sequence[str] = ...,
         SourceIds: Sequence[str] = ...,
         Enabled: bool = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence[TagTypeDef] = ...
     ) -> CreateEventSubscriptionResultTypeDef:
         """
         Creates an Amazon DocumentDB event notification subscription.
@@ -405,7 +408,9 @@ class DocDBClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/client/#delete_db_cluster)
         """
 
-    def delete_db_cluster_parameter_group(self, *, DBClusterParameterGroupName: str) -> None:
+    def delete_db_cluster_parameter_group(
+        self, *, DBClusterParameterGroupName: str
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Deletes a specified cluster parameter group.
 
@@ -431,7 +436,7 @@ class DocDBClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/client/#delete_db_instance)
         """
 
-    def delete_db_subnet_group(self, *, DBSubnetGroupName: str) -> None:
+    def delete_db_subnet_group(self, *, DBSubnetGroupName: str) -> EmptyResponseMetadataTypeDef:
         """
         Deletes a subnet group.
 
@@ -463,7 +468,7 @@ class DocDBClient(BaseClient):
         self,
         *,
         CertificateIdentifier: str = ...,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         MaxRecords: int = ...,
         Marker: str = ...
     ) -> CertificateMessageTypeDef:
@@ -479,7 +484,7 @@ class DocDBClient(BaseClient):
         self,
         *,
         DBClusterParameterGroupName: str = ...,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         MaxRecords: int = ...,
         Marker: str = ...
     ) -> DBClusterParameterGroupsMessageTypeDef:
@@ -495,7 +500,7 @@ class DocDBClient(BaseClient):
         *,
         DBClusterParameterGroupName: str,
         Source: str = ...,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         MaxRecords: int = ...,
         Marker: str = ...
     ) -> DBClusterParameterGroupDetailsTypeDef:
@@ -523,7 +528,7 @@ class DocDBClient(BaseClient):
         DBClusterIdentifier: str = ...,
         DBClusterSnapshotIdentifier: str = ...,
         SnapshotType: str = ...,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         MaxRecords: int = ...,
         Marker: str = ...,
         IncludeShared: bool = ...,
@@ -540,7 +545,7 @@ class DocDBClient(BaseClient):
         self,
         *,
         DBClusterIdentifier: str = ...,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         MaxRecords: int = ...,
         Marker: str = ...
     ) -> DBClusterMessageTypeDef:
@@ -557,7 +562,7 @@ class DocDBClient(BaseClient):
         Engine: str = ...,
         EngineVersion: str = ...,
         DBParameterGroupFamily: str = ...,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         MaxRecords: int = ...,
         Marker: str = ...,
         DefaultOnly: bool = ...,
@@ -575,7 +580,7 @@ class DocDBClient(BaseClient):
         self,
         *,
         DBInstanceIdentifier: str = ...,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         MaxRecords: int = ...,
         Marker: str = ...
     ) -> DBInstanceMessageTypeDef:
@@ -590,7 +595,7 @@ class DocDBClient(BaseClient):
         self,
         *,
         DBSubnetGroupName: str = ...,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         MaxRecords: int = ...,
         Marker: str = ...
     ) -> DBSubnetGroupMessageTypeDef:
@@ -605,7 +610,7 @@ class DocDBClient(BaseClient):
         self,
         *,
         DBParameterGroupFamily: str,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         MaxRecords: int = ...,
         Marker: str = ...
     ) -> DescribeEngineDefaultClusterParametersResultTypeDef:
@@ -618,7 +623,7 @@ class DocDBClient(BaseClient):
         """
 
     def describe_event_categories(
-        self, *, SourceType: str = ..., Filters: Sequence["FilterTypeDef"] = ...
+        self, *, SourceType: str = ..., Filters: Sequence[FilterTypeDef] = ...
     ) -> EventCategoriesMessageTypeDef:
         """
         Displays a list of categories for all event source types, or, if specified, for
@@ -632,7 +637,7 @@ class DocDBClient(BaseClient):
         self,
         *,
         SubscriptionName: str = ...,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         MaxRecords: int = ...,
         Marker: str = ...
     ) -> EventSubscriptionsMessageTypeDef:
@@ -652,7 +657,7 @@ class DocDBClient(BaseClient):
         EndTime: Union[datetime, str] = ...,
         Duration: int = ...,
         EventCategories: Sequence[str] = ...,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         MaxRecords: int = ...,
         Marker: str = ...
     ) -> EventsMessageTypeDef:
@@ -668,7 +673,7 @@ class DocDBClient(BaseClient):
         self,
         *,
         GlobalClusterIdentifier: str = ...,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         MaxRecords: int = ...,
         Marker: str = ...
     ) -> GlobalClustersMessageTypeDef:
@@ -687,7 +692,7 @@ class DocDBClient(BaseClient):
         DBInstanceClass: str = ...,
         LicenseModel: str = ...,
         Vpc: bool = ...,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         MaxRecords: int = ...,
         Marker: str = ...
     ) -> OrderableDBInstanceOptionsMessageTypeDef:
@@ -702,7 +707,7 @@ class DocDBClient(BaseClient):
         self,
         *,
         ResourceIdentifier: str = ...,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         Marker: str = ...,
         MaxRecords: int = ...
     ) -> PendingMaintenanceActionsMessageTypeDef:
@@ -739,7 +744,7 @@ class DocDBClient(BaseClient):
         """
 
     def list_tags_for_resource(
-        self, *, ResourceName: str, Filters: Sequence["FilterTypeDef"] = ...
+        self, *, ResourceName: str, Filters: Sequence[FilterTypeDef] = ...
     ) -> TagListMessageTypeDef:
         """
         Lists all tags on an Amazon DocumentDB resource.
@@ -761,7 +766,7 @@ class DocDBClient(BaseClient):
         MasterUserPassword: str = ...,
         PreferredBackupWindow: str = ...,
         PreferredMaintenanceWindow: str = ...,
-        CloudwatchLogsExportConfiguration: "CloudwatchLogsExportConfigurationTypeDef" = ...,
+        CloudwatchLogsExportConfiguration: CloudwatchLogsExportConfigurationTypeDef = ...,
         EngineVersion: str = ...,
         DeletionProtection: bool = ...
     ) -> ModifyDBClusterResultTypeDef:
@@ -773,7 +778,7 @@ class DocDBClient(BaseClient):
         """
 
     def modify_db_cluster_parameter_group(
-        self, *, DBClusterParameterGroupName: str, Parameters: Sequence["ParameterTypeDef"]
+        self, *, DBClusterParameterGroupName: str, Parameters: Sequence[ParameterTypeDef]
     ) -> DBClusterParameterGroupNameMessageTypeDef:
         """
         Modifies the parameters of a cluster parameter group.
@@ -894,7 +899,9 @@ class DocDBClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/client/#remove_source_identifier_from_subscription)
         """
 
-    def remove_tags_from_resource(self, *, ResourceName: str, TagKeys: Sequence[str]) -> None:
+    def remove_tags_from_resource(
+        self, *, ResourceName: str, TagKeys: Sequence[str]
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Removes metadata tags from an Amazon DocumentDB resource.
 
@@ -907,7 +914,7 @@ class DocDBClient(BaseClient):
         *,
         DBClusterParameterGroupName: str,
         ResetAllParameters: bool = ...,
-        Parameters: Sequence["ParameterTypeDef"] = ...
+        Parameters: Sequence[ParameterTypeDef] = ...
     ) -> DBClusterParameterGroupNameMessageTypeDef:
         """
         Modifies the parameters of a cluster parameter group to the default value.
@@ -927,7 +934,7 @@ class DocDBClient(BaseClient):
         Port: int = ...,
         DBSubnetGroupName: str = ...,
         VpcSecurityGroupIds: Sequence[str] = ...,
-        Tags: Sequence["TagTypeDef"] = ...,
+        Tags: Sequence[TagTypeDef] = ...,
         KmsKeyId: str = ...,
         EnableCloudwatchLogsExports: Sequence[str] = ...,
         DeletionProtection: bool = ...
@@ -949,7 +956,7 @@ class DocDBClient(BaseClient):
         Port: int = ...,
         DBSubnetGroupName: str = ...,
         VpcSecurityGroupIds: Sequence[str] = ...,
-        Tags: Sequence["TagTypeDef"] = ...,
+        Tags: Sequence[TagTypeDef] = ...,
         KmsKeyId: str = ...,
         EnableCloudwatchLogsExports: Sequence[str] = ...,
         DeletionProtection: bool = ...
