@@ -40,10 +40,10 @@ class DBInstanceAvailableWaiter(Boto3Waiter):
         self,
         *,
         DBInstanceIdentifier: str = ...,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         MaxRecords: int = ...,
         Marker: str = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Waiter.DBInstanceAvailable.wait)
@@ -61,10 +61,10 @@ class DBInstanceDeletedWaiter(Boto3Waiter):
         self,
         *,
         DBInstanceIdentifier: str = ...,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         MaxRecords: int = ...,
         Marker: str = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Waiter.DBInstanceDeleted.wait)
